@@ -10,7 +10,7 @@ use File::Spec::Functions qw(catfile);
 use Mojo::Base 'OpenAPI::Client';
 use Mojo::URL;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ( $class, $specification ) = ( shift, shift );
@@ -86,8 +86,9 @@ OpenAPI::Client::Pinecone - A client for the Pinecone API
 
   my $client = OpenAPI::Client::Pinecone->new(); # see ENVIRONMENT VARIABLES
 
-  my $transaction = $client->list_collections();
-  my $response_data = decode_json($transaction->res->body);
+  my $tx = $client->list_collections();
+
+  my $response_data = $tx->res->json;
 
   #print Dumper($response_data);
 
